@@ -1,30 +1,4 @@
 
-test_that("test input parameters errors", {
-  skip_on_cran()
-  cdm <- mockDrugUtilisation(
-    connectionDetails,
-    drug_strength = dplyr::tibble(
-      drug_concept_id = c(1, 2, 3, 4),
-      ingredient_concept_id = c(1, 1, 1, 1),
-      amount_value = c(10, 20, 30, 40),
-      amount_unit_concept_id = c(8576, 8576, 8576, 8576)
-    ),
-    cohort1 = dplyr::tibble(
-      cohort_definition_id = c(1, 1, 1, 2),
-      subject_id = c(1, 1, 1, 2),
-      cohort_start_date = as.Date(c(
-        "2020-01-01", "2022-01-01", "2020-01-01", "2020-01-01"
-      )),
-      cohort_end_date = as.Date(c(
-        "2020-05-01", "2022-09-06", "2020-05-01", "2020-05-01"
-      ))
-    )
-  )
-
-  expect_error(addDrugUse())
-  expect_error(addDrugUse(cdm = cdm))
-})
-
 test_that("test overlapMode", {
   skip_on_cran()
   cdm <- mockDrugUtilisation(
@@ -75,16 +49,20 @@ test_that("test overlapMode", {
       cohort_end_date = as.Date(c("2000-03-01", "2001-03-01", "2000-03-01"))
     )
   )
+  # variables <- c(
+  #   "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
+  #   "number_exposures", "number_subexposures", "number_continuous_exposures",
+  #   "number_eras", "number_gaps", "number_unexposed_periods",
+  #   "number_subexposures_overlap", "number_eras_overlap",
+  #   "number_continuous_exposure_overlap", "initial_daily_dose",
+  #   "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
+  #   "number_subexposures_no_overlap", "number_eras_no_overlap",
+  #   "number_continuous_exposures_no_overlap",
+  #   "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+  # )
   variables <- c(
-    "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
-    "number_exposures", "number_subexposures", "number_continuous_exposures",
-    "number_eras", "number_gaps", "number_unexposed_periods",
-    "number_subexposures_overlap", "number_eras_overlap",
-    "number_continuous_exposure_overlap", "initial_daily_dose",
-    "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
-    "number_subexposures_no_overlap", "number_eras_no_overlap",
-    "number_continuous_exposures_no_overlap",
-    "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+    "number_exposures", "number_eras", "initial_daily_dose", "duration",
+    "cumulative_dose", "initial_quantity", "cumulative_quantity"
   )
 
   # prev
@@ -92,7 +70,6 @@ test_that("test overlapMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Previous",
@@ -102,11 +79,16 @@ test_that("test overlapMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
+
+  expect_equal(sort(names(attributes(cdm$cohort1))), sort(names(attributes(x))))
+  expect_true(all(variables %in% colnames(x)))
+
   value_cohort_1 <- c(
     61, 0, 33, 61, 3, 5, 1, 1, 0, 0, 2, 1, 1, 10, 41 * 10 + 52 * 20 + 30, 41 + 52 + 1, 61,
     0, 3, 0, 0,
     41 * 10 + 20 * 20, 0, 32 * 20 + 30
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 41, 94)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
@@ -121,7 +103,6 @@ test_that("test overlapMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Subsequent",
@@ -135,7 +116,8 @@ test_that("test overlapMode", {
     61, 0, 33, 61, 3, 5, 1, 1, 0, 0, 2, 1, 1, 10, 41 * 10 + 52 * 20 + 30, 41 + 52 + 1, 61,
     0, 3, 0, 0,
     10 * 9 + 20 * 51 + 30 * 1, 0, 10 * 32 + 20 * 1 + 30 * 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 41, 94)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
@@ -150,7 +132,6 @@ test_that("test overlapMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Minimum",
@@ -164,7 +145,8 @@ test_that("test overlapMode", {
     61, 0, 33, 61, 3, 5, 1, 1, 0, 0, 2, 1, 1, 10, 41 * 10 + 52 * 20 + 30, 41 + 52 + 1, 61,
     0, 3, 0, 0,
     10 * 41 + 20 * 20 + 30 * 0, 0, 10 * 0 + 20 * 32 + 30 * 1
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 41, 94)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
@@ -179,7 +161,6 @@ test_that("test overlapMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Maximum",
@@ -193,7 +174,8 @@ test_that("test overlapMode", {
     61, 0, 33, 61, 3, 5, 1, 1, 0, 0, 2, 1, 1, 10, 41 * 10 + 52 * 20 + 30, 41 + 52 + 1, 61,
     0, 3, 0, 0,
     9 * 10 + 51 * 20 + 1 * 30, 0, 32 * 10 + 1 * 20 + 0 * 30
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 41, 94)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
@@ -208,7 +190,6 @@ test_that("test overlapMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Sum",
@@ -222,7 +203,8 @@ test_that("test overlapMode", {
     61, 0, 0, 61, 3, 5, 1, 1, 0, 0, 2, 1, 1, 10, 41 * 10 + 52 * 20 + 30, 41 + 52 + 1, 61,
     0, 3, 0, 0,
     41 * 10 + 52 * 20 + 1 * 30, 0, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 41, 94)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
@@ -284,16 +266,20 @@ test_that("test gapEra and eraJoinMode", {
     )
   )
 
+  # variables <- c(
+  #   "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
+  #   "number_exposures", "number_subexposures", "number_continuous_exposures",
+  #   "number_eras", "number_gaps", "number_unexposed_periods",
+  #   "number_subexposures_overlap", "number_eras_overlap",
+  #   "number_continuous_exposure_overlap", "initial_daily_dose",
+  #   "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
+  #   "number_subexposures_no_overlap", "number_eras_no_overlap",
+  #   "number_continuous_exposures_no_overlap",
+  #   "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+  # )
   variables <- c(
-    "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
-    "number_exposures", "number_subexposures", "number_continuous_exposures",
-    "number_eras", "number_gaps", "number_unexposed_periods",
-    "number_subexposures_overlap", "number_eras_overlap",
-    "number_continuous_exposure_overlap", "initial_daily_dose",
-    "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
-    "number_subexposures_no_overlap", "number_eras_no_overlap",
-    "number_continuous_exposures_no_overlap",
-    "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+    "number_exposures", "number_eras", "initial_daily_dose", "duration",
+    "cumulative_dose", "initial_quantity", "cumulative_quantity"
   )
 
   # overall functionality
@@ -301,7 +287,6 @@ test_that("test gapEra and eraJoinMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 0,
     eraJoinMode = "Previous",
     overlapMode = "Sum",
@@ -311,20 +296,22 @@ test_that("test gapEra and eraJoinMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     35, 25, 0, 15, 2, 3, 2,
     2, 0, 1,
     0, 0, 0, 30, 15 * 30 + 20 * 20, 15 + 20, 60,
     0, 3, 2, 2,
     15 * 30 + 20 * 20, 0, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 15, 35)
+
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
       subject_id == 1 & cohort_start_date == as.Date("2001-01-01")
     )
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 
   # gapEra = 24
@@ -332,7 +319,6 @@ test_that("test gapEra and eraJoinMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 24,
     eraJoinMode = "Previous",
     overlapMode = "Sum",
@@ -342,20 +328,21 @@ test_that("test gapEra and eraJoinMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     35, 25, 0, 15, 2, 3, 2,
     2, 0, 1,
     0, 0, 0, 30, 15 * 30 + 20 * 20, 15 + 20, 60,
     0, 3, 2, 2,
     15 * 30 + 20 * 20, 0, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 15, 35)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
       subject_id == 1 & cohort_start_date == as.Date("2001-01-01")
     )
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 
   # gapEra = 25 & joinMode = Zero
@@ -363,7 +350,6 @@ test_that("test gapEra and eraJoinMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 25,
     eraJoinMode = "Zero",
     overlapMode = "Sum",
@@ -373,20 +359,21 @@ test_that("test gapEra and eraJoinMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     35, 0, 0, 60, 2, 3, 2,
     1, 1, 0,
     0, 0, 0, 30, 15 * 30 + 20 * 20, 15 + 20, 60,
     25, 3, 1, 2,
     15 * 30 + 20 * 20, 0, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 15, 35)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
       subject_id == 1 & cohort_start_date == as.Date("2001-01-01")
     )
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 
   # gapEra = 25 & joinMode = Previous
@@ -394,7 +381,6 @@ test_that("test gapEra and eraJoinMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 25,
     eraJoinMode = "Previous",
     overlapMode = "Sum",
@@ -404,20 +390,21 @@ test_that("test gapEra and eraJoinMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     35, 0, 0, 60, 2, 3, 2,
     1, 1, 0,
     0, 0, 0, 30, 15 * 30 + 20 * 20, 15 + 20, 60,
     25, 3, 1, 2,
     15 * 30 + 20 * 20 + 25 * 30, 25 * 30, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 15, 35)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
       subject_id == 1 & cohort_start_date == as.Date("2001-01-01")
     )
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 
   # gapEra = 25 & joinMode = Subsequent
@@ -425,7 +412,6 @@ test_that("test gapEra and eraJoinMode", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 25,
     eraJoinMode = "Subsequent",
     overlapMode = "Sum",
@@ -435,20 +421,21 @@ test_that("test gapEra and eraJoinMode", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     35, 0, 0, 60, 2, 3, 2,
     1, 1, 0,
     0, 0, 0, 30, 15 * 30 + 20 * 20, 15 + 20, 60,
     25, 3, 1, 2,
     15 * 30 + 20 * 20 + 25 * 20, 25 * 20, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 15, 35)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(
       subject_id == 1 & cohort_start_date == as.Date("2001-01-01")
     )
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 })
 
@@ -503,16 +490,20 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
     )
   )
 
+  # variables <- c(
+  #   "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
+  #   "number_exposures", "number_subexposures", "number_continuous_exposures",
+  #   "number_eras", "number_gaps", "number_unexposed_periods",
+  #   "number_subexposures_overlap", "number_eras_overlap",
+  #   "number_continuous_exposure_overlap", "initial_daily_dose",
+  #   "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
+  #   "number_subexposures_no_overlap", "number_eras_no_overlap",
+  #   "number_continuous_exposures_no_overlap",
+  #   "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+  # )
   variables <- c(
-    "exposed_days", "unexposed_days", "not_considered_days", "first_era_days",
-    "number_exposures", "number_subexposures", "number_continuous_exposures",
-    "number_eras", "number_gaps", "number_unexposed_periods",
-    "number_subexposures_overlap", "number_eras_overlap",
-    "number_continuous_exposure_overlap", "initial_daily_dose",
-    "sum_all_exposed_dose", "sum_all_exposed_days", "duration", "gap_days",
-    "number_subexposures_no_overlap", "number_eras_no_overlap",
-    "number_continuous_exposures_no_overlap",
-    "cumulative_dose", "cumulative_gap_dose", "cumulative_not_considered_dose"
+    "number_exposures", "number_eras", "initial_daily_dose", "duration",
+    "cumulative_dose", "initial_quantity", "cumulative_quantity"
   )
 
   # overall functionality
@@ -520,7 +511,6 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 0,
     eraJoinMode = "Zero",
     overlapMode = "Sum",
@@ -530,18 +520,19 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
     durationRange = c(1, Inf),
     dailyDoseRange = c(0, Inf)
   ))
-  values <- c(
+  value_cohort_1 <- c(
     28, 33, 0, 27, 4, 7, 2,
     2, 0, 3,
     2, 1, 1, 0, 30 * 16 + 40 * 22 + 10 * 22 + 20 * 1, 16 + 22 + 22 + 1, 61,
     0, 5, 1, 1,
     30 * 16 + 40 * 22 + 10 * 22 + 20 * 1, 0, 0
-  )
+  )[c(5, 8, 14, 17, 22)]
+  value_cohort_1 <- c(value_cohort_1, 0, 61)
   xx <- x %>%
     dplyr::collect() %>%
     dplyr::filter(subject_id == 2)
-  for (k in 1:length(values)) {
-    expect_true(xx[[variables[k]]] == values[k])
+  for (k in 1:length(value_cohort_1)) {
+    expect_true(xx[[variables[k]]] == value_cohort_1[k])
   }
 
   parameters <- dplyr::tibble(
@@ -559,15 +550,15 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
     gapEra = c(8, 8, 16, 8, 16, 16, 16, 16)
   )
   expected_result <- dplyr::tibble(
-    first_era_length = c(27, 27, 37, 27, 37, 37, 37, 37),
-    not_considered_days = c(0, 33, 33, 33, 33, 22, 22, 11),
+    #first_era_length = c(27, 27, 37, 27, 37, 37, 37, 37),
+    #not_considered_days = c(0, 33, 33, 33, 33, 22, 22, 11),
     number_eras = c(2, 2, 1, 2, 1, 1, 1, 1),
-    number_gaps = c(0, 0, 1, 0, 1, 1, 1, 1),
-    unexposed_days = c(33, 33, 24, 33, 24, 24, 24, 24),
-    gap_days = c(0, 0, 9, 0, 9, 9, 9, 9),
+    #number_gaps = c(0, 0, 1, 0, 1, 1, 1, 1),
+    #unexposed_days = c(33, 33, 24, 33, 24, 24, 24, 24),
+    #gap_days = c(0, 0, 9, 0, 9, 9, 9, 9),
     cumulative_dose = c(1600, 610, 1410, 1050, 1720, 900, 810, 1720),
-    cumulative_gap_dose = c(0, 0, 360, 0, 450, 180, 90, 450),
-    cumulative_not_considered_dose = c(0, 990, 550, 550, 330, 880, 880, 330)
+    #cumulative_gap_dose = c(0, 0, 360, 0, 450, 180, 90, 450),
+    #cumulative_not_considered_dose = c(0, 990, 550, 550, 330, 880, 880, 330)
   )
 
   for (k in 1:nrow(parameters)) {
@@ -575,7 +566,6 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
       cohort = cdm$cohort1,
       cdm = cdm,
       ingredientConceptId = 1,
-      supplementary = TRUE,
       gapEra = parameters$gapEra[k],
       eraJoinMode = parameters$eraJoinMode[k],
       overlapMode = parameters$overlapMode[k],
@@ -588,22 +578,22 @@ test_that("test gapEra, eraJoinMode & sameIndexOverlap", {
     result <- x %>%
       dplyr::collect() %>%
       dplyr::filter(subject_id == 2)
-    expect_true(result$first_era_days == expected_result$first_era_length[k])
-    expect_true(
-      result$not_considered_days == expected_result$not_considered_days[k]
-    )
+    #expect_true(result$first_era_days == expected_result$first_era_length[k])
+    #expect_true(
+    #  result$not_considered_days == expected_result$not_considered_days[k]
+    #)
     expect_true(result$number_eras == expected_result$number_eras[k])
-    expect_true(result$number_gaps == expected_result$number_gaps[k])
-    expect_true(result$unexposed_days == expected_result$unexposed_days[k])
-    expect_true(result$gap_days == expected_result$gap_days[k])
+    #expect_true(result$number_gaps == expected_result$number_gaps[k])
+    #expect_true(result$unexposed_days == expected_result$unexposed_days[k])
+    #expect_true(result$gap_days == expected_result$gap_days[k])
     expect_true(result$cumulative_dose == expected_result$cumulative_dose[k])
-    expect_true(
-      result$cumulative_gap_dose == expected_result$cumulative_gap_dose[k]
-    )
-    expect_true(
-      result$cumulative_not_considered_dose ==
-        expected_result$cumulative_not_considered_dose[k]
-    )
+    #expect_true(
+    #  result$cumulative_gap_dose == expected_result$cumulative_gap_dose[k]
+    #)
+    #expect_true(
+    #  result$cumulative_not_considered_dose ==
+    #    expected_result$cumulative_not_considered_dose[k]
+    #)
   }
 })
 
@@ -895,7 +885,6 @@ test_that("test empty targetCohortName", {
     cohort = cdm$cohort1,
     cdm = cdm,
     ingredientConceptId = 1,
-    supplementary = TRUE,
     gapEra = 30,
     eraJoinMode = "Previous",
     overlapMode = "Previous",
@@ -973,7 +962,7 @@ test_that("check output format", {
   expect_true(all(colnames(result) %in% c(
     "group_name", "group_level", "strata_name", "strata_level", "variable",
     "variable_level", "variable_type", "estimate_type", "estimate", "cdm_name",
-    "generated_by"
+    "result_type"
   )))
 })
 
@@ -1026,5 +1015,24 @@ test_that("check all estimates", {
     drugUseEstimates = all_estimates
   )
 
-  expect_true(grepl("summariseDrugUse", unique(res$generated_by)))
+  expect_true(grepl("Summary drug use", unique(res$result_type)))
+})
+
+test_that("check all variables", {
+  all_estimates <- c(
+    "min", "max", "mean", "median", "iqr", "range", "q05", "q10", "q15", "q20",
+    "q25", "q30", "q35", "q40", "q45", "q55", "q60", "q65", "q70",
+    "q75", "q80", "q85", "q90", "q95", "sd"
+  )
+  cdm <- mockDrugUtilisation(connectionDetails)
+  cdm <- generateDrugUtilisationCohortSet(
+    cdm, "dus", list(acetaminophen = c(1125315, 43135274, 2905077, 1125360))
+  )
+  result <- cdm$dus %>%
+    addDrugUse(cdm, 1125315) %>%
+    summariseDrugUse(cdm, drugUseEstimates = all_estimates)
+  expect_true(all(c(
+    "initial_daily_dose", "number_exposures", "duration", "cumulative_dose",
+    "number_eras", "initial_quantity", "cumulative_quantity"
+  ) %in% result$variable))
 })
