@@ -2,6 +2,10 @@ test_that("test inputs", {
   cdm <- mockDrugUtilisation(connectionDetails)
   indications <- list(headache = 378253, influenza = 4266367, rand = 12345678)
   expect_no_error(cdm <- generateConceptCohortSet(
-    cdm, "indications_cohort", indications
+    cdm, indications, "indications_cohort"
   ))
+
+  #check cdm reference in attributes
+  expect_true(!is.null(attr(cdm$indications_cohort,"cdm_reference",exact = TRUE)))
+
 })
